# Poland 2D Line 001
[SEG Wiki Open Data](https://wiki.seg.org/wiki/2D_Vibroseis_Line_001)

### Acquisition Parameters
Parameter | Value
--------- | -----
Nominal Receiver Station Interval | 25.0m
Nominal Source Station Interval | 50.0m
First SP Station Number | 701
Last SP Station Number | 1201
First Live Station Number | 561
Last Live Station Number | 1342
Original Reference Level | 0.0
Reference Velocity | 1900.0
Source Skid | 12.50
Source | Vibroseis
Sweep type | UP +3db/oct
Sweep freq | 8Hz-95Hz
Sweep length | Cosine,0.3sec,0.5sec
Taper,length start,end | 1342
Geophone type | SM-4
Geophone freq | 10Hz
No. of geophones per group | 24
Geophone array | 25m (linear)


